The Utilities Module
====================

The Utilities Module provides utilities, e.g., for easy access to public measurement
databases.

Currently, it consists of only the :doc:`UIUC database access helper <packages/utils/uiuc_db>`
for accessing the propeller database of the University of Illinois Urbana-Champaign.

.. toctree::
    :hidden:
    :glob:
    :maxdepth: 4

    packages/utils/*
